@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -52,6 +44,8 @@
 #include <QDebug>
 #include <QCoreApplication>
 
+#include <algorithm>
+
 QT_BEGIN_NAMESPACE
 
 static const QDeclarativeItemPrivate::ChangeTypes watchedChanges
@@ -230,7 +224,7 @@ void QDeclarativeBasePositioner::prePositioning()
     d->doingPositioning = true;
     //Need to order children by creation order modified by stacking order
     QList<QGraphicsItem *> children = d->QGraphicsItemPrivate::children;
-    qSort(children.begin(), children.end(), d->insertionOrder);
+    std::sort(children.begin(), children.end(), QGraphicsItemPrivate::insertionOrder);
 
     QPODVector<PositionedItem,8> oldItems;
     positionedItems.copyAndClear(oldItems);
@@ -495,7 +489,7 @@ void QDeclarativeColumn::reportConflictingAnchors()
   \inherits Item
 
   The Row item positions its child items so that they are horizontally
-  aligned and not overlapping. 
+  aligned and not overlapping.
 
   Use \l spacing to set the spacing between items in a Row, and use the
   \l add and \l move properties to set the transitions that should be applied
@@ -710,7 +704,7 @@ void QDeclarativeRow::reportConflictingAnchors()
   \inherits Item
 
   The Grid item positions its child items so that they are
-  aligned in a grid and are not overlapping. 
+  aligned in a grid and are not overlapping.
 
   The grid positioner calculates a grid of rectangular cells of sufficient
   size to hold all items, placing the items in the cells, from left to right
