@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -71,7 +63,7 @@ QDeclarativeAbstractBinding::~QDeclarativeAbstractBinding()
 /*!
 Destroy the binding.  Use this instead of calling delete.
 
-Bindings are free to implement their own memory management, so the delete operator is not 
+Bindings are free to implement their own memory management, so the delete operator is not
 necessarily safe.  The default implementation clears the binding, removes it from the object
 and calls delete.
 */
@@ -87,7 +79,7 @@ void QDeclarativeAbstractBinding::destroy()
 Add this binding to \a object.
 
 This transfers ownership of the binding to the object, marks the object's property as
-being bound.  
+being bound.
 
 However, it does not enable the binding itself or call update() on it.
 */
@@ -227,8 +219,8 @@ QDeclarativeBindingPrivate::~QDeclarativeBindingPrivate()
     if (deleted) *deleted = true;
 }
 
-QDeclarativeBinding::QDeclarativeBinding(void *data, QDeclarativeRefCount *rc, QObject *obj, 
-                                         QDeclarativeContextData *ctxt, const QString &url, int lineNumber, 
+QDeclarativeBinding::QDeclarativeBinding(void *data, QDeclarativeRefCount *rc, QObject *obj,
+                                         QDeclarativeContextData *ctxt, const QString &url, int lineNumber,
                                          QObject *parent)
 : QDeclarativeExpression(ctxt, data, rc, obj, url, lineNumber, *new QDeclarativeBindingPrivate)
 {
@@ -253,7 +245,8 @@ QDeclarativeBinding::createBinding(Identifier id, QObject *obj, QDeclarativeCont
         typeData = engine->typeLoader.get(ctxtdata->url);
         cdata = typeData->compiledData();
     }
-    QDeclarativeBinding *rv = cdata ? new QDeclarativeBinding((void*)cdata->datas.at(id).constData(), cdata, obj, ctxtdata, url, lineNumber, parent) : 0;
+    QDeclarativeBinding *rv = cdata ? new QDeclarativeBinding(const_cast<char *>(cdata->datas.at(id).constData()),
+                                                              cdata, obj, ctxtdata, url, lineNumber, parent) : 0;
     if (cdata)
         cdata->release();
     if (typeData)
@@ -261,7 +254,7 @@ QDeclarativeBinding::createBinding(Identifier id, QObject *obj, QDeclarativeCont
     return rv;
 }
 
-QDeclarativeBinding::QDeclarativeBinding(const QString &str, QObject *obj, QDeclarativeContext *ctxt, 
+QDeclarativeBinding::QDeclarativeBinding(const QString &str, QObject *obj, QDeclarativeContext *ctxt,
                                          QObject *parent)
 : QDeclarativeExpression(QDeclarativeContextData::get(ctxt), obj, str, *new QDeclarativeBindingPrivate)
 {
@@ -269,7 +262,7 @@ QDeclarativeBinding::QDeclarativeBinding(const QString &str, QObject *obj, QDecl
     setNotifyOnValueChanged(true);
 }
 
-QDeclarativeBinding::QDeclarativeBinding(const QString &str, QObject *obj, QDeclarativeContextData *ctxt, 
+QDeclarativeBinding::QDeclarativeBinding(const QString &str, QObject *obj, QDeclarativeContextData *ctxt,
                                          QObject *parent)
 : QDeclarativeExpression(ctxt, obj, str, *new QDeclarativeBindingPrivate)
 {
@@ -296,10 +289,10 @@ void QDeclarativeBinding::setTarget(const QDeclarativeProperty &prop)
     update();
 }
 
-QDeclarativeProperty QDeclarativeBinding::property() const 
+QDeclarativeProperty QDeclarativeBinding::property() const
 {
    Q_D(const QDeclarativeBinding);
-   return d->property; 
+   return d->property;
 }
 
 void QDeclarativeBinding::setEvaluateFlags(EvaluateFlags flags)
@@ -334,7 +327,7 @@ void QDeclarativeBinding::update(QDeclarativePropertyPrivate::WriteFlags flags)
 {
     Q_D(QDeclarativeBinding);
 
-    if (!d->enabled || !d->context() || !d->context()->isValid()) 
+    if (!d->enabled || !d->context() || !d->context()->isValid())
         return;
 
     if (!d->updating) {
@@ -370,7 +363,7 @@ void QDeclarativeBinding::update(QDeclarativePropertyPrivate::WriteFlags flags)
 
             if (d->property.propertyTypeCategory() == QDeclarativeProperty::List) {
                 value = ep->scriptValueToVariant(scriptValue, qMetaTypeId<QList<QObject *> >());
-            } else if (scriptValue.isNull() && 
+            } else if (scriptValue.isNull() &&
                        d->property.propertyTypeCategory() == QDeclarativeProperty::Object) {
                 value = QVariant::fromValue((QObject *)0);
             } else {
@@ -469,7 +462,7 @@ void QDeclarativeBinding::setEnabled(bool e, QDeclarativePropertyPrivate::WriteF
     d->enabled = e;
     setNotifyOnValueChanged(e);
 
-    if (e) 
+    if (e)
         update(flags);
 }
 
@@ -541,8 +534,8 @@ void QDeclarativeValueTypeProxyBinding::update(QDeclarativePropertyPrivate::Writ
 QDeclarativeAbstractBinding *QDeclarativeValueTypeProxyBinding::binding(int propertyIndex)
 {
     QDeclarativeAbstractBinding *binding = m_bindings;
-    
-    while (binding && binding->propertyIndex() != propertyIndex) 
+
+    while (binding && binding->propertyIndex() != propertyIndex)
         binding = binding->m_nextBinding;
 
     return binding;
