@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -82,7 +74,7 @@ void qdeclarativelistmodel_move(int from, int to, int n, T *items)
 
 QDeclarativeListModelParser::ListInstruction *QDeclarativeListModelParser::ListModelData::instructions() const
 {
-    return (QDeclarativeListModelParser::ListInstruction *)((char *)this + sizeof(ListModelData));
+    return (QDeclarativeListModelParser::ListInstruction *)(const_cast<char *>((const char *)this) + sizeof(ListModelData));
 }
 
 /*!
@@ -210,7 +202,7 @@ QDeclarativeListModelParser::ListInstruction *QDeclarativeListModelParser::ListM
     when retrieved from get() is accessible as a list model within the list
     model) whereas a FlatListModel cannot.
 
-    ListModel uses a NestedListModel to begin with, and if the model is later 
+    ListModel uses a NestedListModel to begin with, and if the model is later
     used from a WorkerScript, it changes to use a FlatListModel instead. This
     is because ModelNode (which abstracts the nested list model data) needs
     access to the declarative engine and script engine, which cannot be
@@ -351,7 +343,7 @@ void QDeclarativeListModel::clear()
 
 QDeclarativeListModel *ModelNode::model(const NestedListModel *model)
 {
-    if (!modelCache) { 
+    if (!modelCache) {
         modelCache = new QDeclarativeListModel;
         QDeclarativeEngine::setContextForObject(modelCache,QDeclarativeEngine::contextForObject(model->m_listModel));
         modelCache->m_nested->_root = this;  // ListModel defaults to nestable model
@@ -368,8 +360,8 @@ QDeclarativeListModel *ModelNode::model(const NestedListModel *model)
 ModelObject *ModelNode::object(const NestedListModel *model)
 {
     if (!objectCache) {
-        objectCache = new ModelObject(this, 
-                const_cast<NestedListModel*>(model), 
+        objectCache = new ModelObject(this,
+                const_cast<NestedListModel*>(model),
                 QDeclarativeEnginePrivate::getScriptEngine(qmlEngine(model->m_listModel)));
         QHash<QString, ModelNode *>::iterator it;
         for (it = properties.begin(); it != properties.end(); ++it) {
@@ -984,7 +976,7 @@ QScriptValue FlatListModel::get(int index) const
 {
     QScriptEngine *scriptEngine = m_scriptEngine ? m_scriptEngine : QDeclarativeEnginePrivate::getScriptEngine(qmlEngine(m_listModel));
 
-    if (!scriptEngine) 
+    if (!scriptEngine)
         return 0;
 
     if (index < 0 || index >= m_values.count())
@@ -1101,7 +1093,7 @@ void FlatListModel::moveNodes(int from, int to, int n)
     qdeclarativelistmodel_move<QList<FlatNodeData *> >(from, to, n, &m_nodeData);
 
     for (int i=from; i<from + (to-from); i++)  {
-        if (m_nodeData[i]) 
+        if (m_nodeData[i])
             m_nodeData[i]->index = i;
     }
 }
@@ -1116,7 +1108,7 @@ FlatNodeData::~FlatNodeData()
     }
 }
 
-void FlatNodeData::addData(FlatNodeObjectData *data) 
+void FlatNodeData::addData(FlatNodeObjectData *data)
 {
     objects.insert(data);
 }
@@ -1343,9 +1335,9 @@ void NestedListModel::move(int from, int to, int n)
 }
 
 QScriptValue NestedListModel::get(int index) const
-{   
+{
     QDeclarativeEngine *eng = qmlEngine(m_listModel);
-    if (!eng) 
+    if (!eng)
         return 0;
 
     if (index < 0 || index >= count()) {
@@ -1358,7 +1350,7 @@ QScriptValue NestedListModel::get(int index) const
     ModelNode *node = qvariant_cast<ModelNode *>(_root->values.at(index));
     if (!node)
         return 0;
-    
+
     return QDeclarativeEnginePrivate::qmlScriptObject(node->object(this), eng);
 }
 
