@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -340,8 +332,8 @@ bool QDeclarativeStateGroupPrivate::updateAutoState()
         if (state->isWhenKnown()) {
             if (state->isNamed()) {
                 if (state->when() && state->when()->evaluate().toBool()) {
-                    if (stateChangeDebug()) 
-                        qWarning() << "Setting auto state due to:" 
+                    if (stateChangeDebug())
+                        qWarning() << "Setting auto state due to:"
                                    << state->when()->expression();
                     if (currentState != state->name()) {
                         q->setState(state->name());
@@ -376,7 +368,7 @@ QDeclarativeTransition *QDeclarativeStateGroupPrivate::findTransition(const QStr
         for (int ii = 0; ii < 2; ++ii)
         {
             if (ii && (!t->reversible() ||
-                      (t->fromState() == QLatin1String("*") && 
+                      (t->fromState() == QLatin1String("*") &&
                        t->toState() == QLatin1String("*"))))
                 break;
             QStringList fromState;
@@ -423,7 +415,7 @@ QDeclarativeTransition *QDeclarativeStateGroupPrivate::findTransition(const QStr
     return highest;
 }
 
-void QDeclarativeStateGroupPrivate::setCurrentStateInternal(const QString &state, 
+void QDeclarativeStateGroupPrivate::setCurrentStateInternal(const QString &state,
                                                    bool ignoreTrans)
 {
     Q_Q(QDeclarativeStateGroup);
@@ -439,11 +431,11 @@ void QDeclarativeStateGroupPrivate::setCurrentStateInternal(const QString &state
 
     applyingState = true;
 
-    QDeclarativeTransition *transition = (ignoreTrans || ignoreTrans) ? 0 : findTransition(currentState, state);
+    QDeclarativeTransition *transition = ignoreTrans ? 0 : findTransition(currentState, state);
     if (stateChangeDebug()) {
         qWarning() << this << "Changing state.  From" << currentState << ". To" << state;
         if (transition)
-            qWarning() << "   using transition" << transition->fromState() 
+            qWarning() << "   using transition" << transition->fromState()
                        << transition->toState();
     }
 
