@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -235,7 +227,7 @@ private:
     QCOMPARE(obj->property("test"), value); \
 \
     delete obj; \
-} 
+}
 
 void tst_qdeclarativecontext::setContextProperty()
 {
@@ -277,56 +269,56 @@ void tst_qdeclarativecontext::setContextProperty()
 
     // Changes in context properties
     {
-        QDeclarativeComponent component(&engine); 
+        QDeclarativeComponent component(&engine);
         component.setData("import QtQuick 1.0; QtObject { property variant test: a }", QUrl());
 
-        QObject *obj = component.create(&ctxt2); 
+        QObject *obj = component.create(&ctxt2);
 
-        QCOMPARE(obj->property("test"), QVariant(13)); 
+        QCOMPARE(obj->property("test"), QVariant(13));
         ctxt.setContextProperty("a", QVariant(19));
-        QCOMPARE(obj->property("test"), QVariant(19)); 
+        QCOMPARE(obj->property("test"), QVariant(19));
 
-        delete obj; 
+        delete obj;
     }
     {
-        QDeclarativeComponent component(&engine); 
+        QDeclarativeComponent component(&engine);
         component.setData("import QtQuick 1.0; QtObject { property variant test: b }", QUrl());
 
-        QObject *obj = component.create(&ctxt2); 
+        QObject *obj = component.create(&ctxt2);
 
-        QCOMPARE(obj->property("test"), QVariant(8)); 
+        QCOMPARE(obj->property("test"), QVariant(8));
         ctxt.setContextProperty("b", QVariant(5));
-        QCOMPARE(obj->property("test"), QVariant(8)); 
+        QCOMPARE(obj->property("test"), QVariant(8));
         ctxt2.setContextProperty("b", QVariant(1912));
-        QCOMPARE(obj->property("test"), QVariant(1912)); 
+        QCOMPARE(obj->property("test"), QVariant(1912));
 
-        delete obj; 
+        delete obj;
     }
     {
-        QDeclarativeComponent component(&engine); 
+        QDeclarativeComponent component(&engine);
         component.setData("import QtQuick 1.0; QtObject { property variant test: e.a }", QUrl());
 
-        QObject *obj = component.create(&ctxt2); 
+        QObject *obj = component.create(&ctxt2);
 
-        QCOMPARE(obj->property("test"), QVariant(12)); 
+        QCOMPARE(obj->property("test"), QVariant(12));
         obj1.setA(13);
-        QCOMPARE(obj->property("test"), QVariant(13)); 
+        QCOMPARE(obj->property("test"), QVariant(13));
 
-        delete obj; 
+        delete obj;
     }
 
     // New context properties
     {
-        QDeclarativeComponent component(&engine); 
+        QDeclarativeComponent component(&engine);
         component.setData("import QtQuick 1.0; QtObject { property variant test: a }", QUrl());
 
-        QObject *obj = component.create(&ctxt2); 
+        QObject *obj = component.create(&ctxt2);
 
-        QCOMPARE(obj->property("test"), QVariant(19)); 
+        QCOMPARE(obj->property("test"), QVariant(19));
         ctxt2.setContextProperty("a", QVariant(1945));
-        QCOMPARE(obj->property("test"), QVariant(1945)); 
+        QCOMPARE(obj->property("test"), QVariant(1945));
 
-        delete obj; 
+        delete obj;
     }
 
     // Setting an object-variant context property
@@ -337,7 +329,7 @@ void tst_qdeclarativecontext::setContextProperty()
         QDeclarativeContext ctxt(engine.rootContext());
         ctxt.setContextProperty("ctxtProp", QVariant());
 
-        QTest::ignoreMessage(QtWarningMsg, "<Unknown File>: TypeError: Result of expression 'ctxtProp' [undefined] is not an object.");
+        QTest::ignoreMessage(QtWarningMsg, "<Unknown File>:1: TypeError: Result of expression 'ctxtProp' [undefined] is not an object.");
         QObject *obj = component.create(&ctxt);
 
         QVariant v = obj->property("obj");
@@ -379,16 +371,16 @@ void tst_qdeclarativecontext::setContextObject()
 
     // Changes in context properties
     {
-        QDeclarativeComponent component(&engine); 
+        QDeclarativeComponent component(&engine);
         component.setData("import QtQuick 1.0; QtObject { property variant test: a }", QUrl());
 
-        QObject *obj = component.create(&ctxt); 
+        QObject *obj = component.create(&ctxt);
 
-        QCOMPARE(obj->property("test"), QVariant(12)); 
+        QCOMPARE(obj->property("test"), QVariant(12));
         to.setA(14);
-        QCOMPARE(obj->property("test"), QVariant(14)); 
+        QCOMPARE(obj->property("test"), QVariant(14));
 
-        delete obj; 
+        delete obj;
     }
 }
 
